package environment.event;

import java.rmi.Remote;
import java.rmi.RemoteException;

/** 
 * Listener interface to register for TimerEvents. The
 * class that implements the TimerListener interface must
 * provide an implementation for the timerExpired() method.
 *
 * When coupled with the traffic light simulator the timer
 * will be synchronized with the simulation time. To do this
 * this timer will the be realized as a remote object and therefore,
 * must extend Remote.
 * 
 * @author Andreas Metzger
 * @version 1.0
 */

public interface TimerListener extends Remote {
    
	/** This method is invoked by the source object of the TimerEvent
	 * if such an event occurrs.
	 * @param e The event that lead to invoking this method.
	 * @throws All RMI objects throw this exception.
	 */
	public void timerExpired(TimerEvent e) throws RemoteException;
}
