package environment.rmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

import environment.event.FehlerListener;

/**
 * Interface for remote object 'Signalgeber'. Use this
 * object to control the traffic lights in the environment
 * of the embedded system. You can retrieve references to
 * Signalgeber remote objects through the 
 * {@link environment.rmi.Verkehrsleitsystem}
 * class (will be available when Interface to simulator is introduced
 * in 'Implementierung III'). Upon initialization
 * a 'Signalgeber' object will be in an arbitrary state.
 *
 * @author Andreas Metzger
 * @version 1.1
 */
public interface Signalgeber extends Remote {

	/**
	 *  Light signal for objects of type 'Signalgeber'
	 */
	public static int ROT = 0;

	/**
	 *  Light signal for objects of type 'Signalgeber'
	 */
	public static int ROTGELB = 1;

	/**
	 *  Light signal for objects of type 'Signalgeber' 
	 */
	public static int GRUEN = 2; 

	/**
	 *  Light signal for objects of type 'Signalgeber'
	 */
	public static int GELB = 3; 

	/**
	 *  Light signal for objects of type 'Signalgeber'
	 */
	 public static int DUNKEL = 4; 

	/** Set signal to one of the possible states (see documentation for fields).
	 * @param signal Light signal of traffic light.
	 * @throws RemoteException All RMI objects throw this exception.
	 */
	public void setLichtsignal(int signal) throws RemoteException;

	/** Get state of traffic light.
	 * @throws RemoteException All RMI objects throw this exception.
	 * @return  State of traffic light.
	 */
	public int getLichtsignal() throws RemoteException;

	/** Adds an implementation of FehlerListener whose
	 *  errorDetected() method is invoked when
	 *  an error in a 'Signalgeber' is detected.
	 * @param fl FehlerListener for FehlerEvents of this Signalgeber.
	 * @throws RemoteException All RMI objects throw this exception.
	 */
	public void addFehlerListener(FehlerListener fl) throws RemoteException;

	/** Removes a FehlerListener.
	 * @param fl FehlerListener for FehlerEvents of this Signalgeber.
	 * @throws RemoteException All RMI objects throw this exception.
	 */
	public void removeFehlerListener(FehlerListener fl) throws RemoteException;

    	/** Repair traffic light (Signalgeber). After invoking this method on a defect traffic light,
	 * subsequent calls to setLichtsignal will function successfully.
	 * @throws RemoteException All RMI objects throw this exception.
	 */
	public void repairLichtsignal() throws RemoteException;

}
